@@ -2,4 +2,4 @@ import importlib.metadata
 
 __version__: str = importlib.metadata.version("pelc")
 
-from . import epitope_comparison, epitope_comparison_aux, output_type
+from . import batch_eplet_comp, batch_eplet_comp_aux, output_type
